@@ -2,6 +2,7 @@
 from .splitter import CSplitter, CPersistentSplitter
 from .buttons import StateButton, IconToggleButton, ConfirmToggleButton
 from .labeledit import LabelEdit
+from .link_label import LinkLabel
 from .line_widgets import VLine, HLine
 from .persistent_widgets import (
     PersistentTabWidget,
@@ -11,4 +12,5 @@ from .persistent_widgets import (
     PersistentListWidget,
     PersistentTreeWidget,
     PersistentComboBox,
+    PersistentCheckableAction,
 )
\ No newline at end of file
